@@ -1,11 +1,11 @@
 import torch
 from .modules import ResnetModule
-from .Model import Model
-from .concerns import Trainable
+from .ClassificationModel import ClassificationModel
+from .concerns import Trainable, ReportsMetrics
 from ..device import get_device
 
 
-class Resnet(Model, Trainable):
+class Resnet(ClassificationModel, Trainable, ReportsMetrics):
     def __init__(self, num_classes: int, lr: float):
         super().__init__()
         self.network = ResnetModule(num_classes).to(get_device())
